@@ -45,6 +45,11 @@ CONJUNCTIVE = 'conjunctive'
 IND = 'ind'
 MODAL = 'modal'
 
+# accents
+ULTIMATE = 'ultimate'
+PENULTIMATE = 'penultimate'
+ANTEPENULTIMATE = 'antepenultimate'
+
 # var
 GENDER = 'gender'
 CONJUGATION_IND = 'conjugation_ind'
@@ -56,6 +61,12 @@ IMPER = 'imper'
 ADJ = 'adj'
 COMP = 'comp'
 COMP_ADV = 'comp_adv'
+ADVERB = 'adverb'
+ADV = 'adv'
+SUPERL = 'superl'
+SUPERL_ADV = 'superl_adv'
+COMPARATIVE = 'comparative'
+ADVERB_COMPARATIVE = 'adverb_comparative'
 # aspect
 
 PERF = 'perf'
@@ -73,7 +84,6 @@ MASC_SG = 'masc_sg'
 NEUT_SG = 'neut_sg'
 ONLY_SG = 'only_sg'
 
-
 forms_with_alternatives = ('ακόμη', 'ακόμα', 'και', 'κι', 'τίποτα', 'τίποτε')
 dictionary_with_alt = {'ακόμη': 'ακόμα', 'και': 'κι', 'τίποτα': 'τίποτε'}
 
@@ -445,8 +455,8 @@ EAUTO = {
 }
 
 irregular_active_roots = \
-    [['ανεβαίν', 'ανέβ,ανεβ'], ['κατεβαίν', 'κατέβ,κατεβ'], ['αίρ', 'άρ'], ['βάλλ', 'βάλ'], ['λαμβάν', 'λάβ'],
-     ['βάζ', 'βάσ'], ['βάζ', 'βάλ'], ['βγάζ', 'βγάλ'], ['λαβαίν', 'λάβ'], ['αγγέλν', 'αγγείλ'], ['αγγέλλ', 'αγγείλ'],
+    [['ανεβαίν', 'ανέβ,ανεβ'], ['πον', 'πονέσ'], ['κατεβαίν', 'κατέβ,κατεβ'], ['αίρ', 'άρ'], ['βάλλ', 'βάλ'], ['απολαμβάν', 'απολαύσ'], ['λαμβάν', 'λάβ'],
+     ['βάζ', 'βάλ'], ['βγάζ', 'βγάλ'], ['λαβαίν', 'λάβ'], ['αγγέλν', 'αγγείλ'], ['αγγέλλ', 'αγγείλ'],
      ['στάν', 'στήσ'], ['σταίν', 'στήσ'], ['πίπτ', 'πέσ'], ['φέρν', 'φέρ'], ['φεύγ', 'φύγ'], ['άγ', 'αγάγ'],
      ['γέρν', 'γεράσ'], ['πάσχ', 'πάθ'], ['σέρν', 'σύρ'], ['τέμν', 'τμήσ'], ['εφιστ', 'επιστήσ'],
      ['καθιστ', 'καταστήσ'], ['λανθάν', 'λάθ'], ['λαγχάνω', 'λάχ'], ['λαχαίν', 'λάχ'], ['αίρν', 'άρ'], ['αίρ', 'άρ'],
@@ -458,34 +468,37 @@ irregular_active_roots = \
      ['τείν', 'τείν'], ['πέφτ', 'πέσ'], ['πέπτ', 'πέσ'], ['πηγαίν', 'πά'], ['τυχαίν', 'τύχ'], ['πετυχαίν', 'πετύχ'],
      ['τυγχάν', 'τύχ'], ['άσχ', 'ασχέσ'], ['τρέφ', 'θρέψ'], ['ελαύν', 'ελάσ'], ['κρέμ', 'κρεμάσ'], ['ευρίσκ', 'εύρ'],
      ['έχ', 'άσχ'], ['έλκ', 'έλκυσ'], ['θαρρ', 'θαρρέψ'], ['χέ', 'χύσ'], ['νιστ', 'στήσ'], ['ιστάν', 'αστήσ'],
-     ['σπά', 'σπάσ'], ['θέλ', 'θελήσ'],
+     ['σπά', 'σπάσ'], ['θέλ', 'θελήσ'], ['κρίν', 'κρίν'], ['νέμ', 'νείμ'],
      ['δεικνύ', 'δείξ'], ['μειγνύ', 'μείξ'], ['ρηγνύ', 'ρήξ'], ['γιγνώσκ', 'γνώσ'], ['πηγνύ', 'πήξ'], ['τρώ', 'φά,φάγ'],
      ['τρώγ', 'φά,φάγ'], ['πά', 'πά'], ['φυλ', 'φυλάξ']]
 
 irregular_passive_roots = \
-    [['βάλλ', 'βληθ'], ['βάζ', 'βαλθ'], ['αίρ', 'αρθ'], ['βγάζ', 'βγαλθ'], ['λαμβάν', 'ληφθ'], ['λαβαίν', 'ληφθ'],
-     ['ρήγνυ', 'ραγ,ρηχθ'], ['ρηγνύ', 'ραγ,ρηχθ'], ['αίρν', 'αρθ'], ['γράφ', 'γραφ,γραφτ'], ['αίρ', 'αρθ'],
+    [['βάλλ', 'βληθ'], ['βάζ', 'βαλθ'], ['αίρ', 'αρθ'], ['βγάζ', 'βγαλθ'], ['λαμβάν', 'ληφθ'], ['πον', 'πονεθ'],
+     ['ρήγνυ', 'ραγ,ρηχθ,ρηχτ'], ['ρηγνύ', 'ραγ,ρηχθ,ρηχτ'], ['αίρν', 'αρθ'], ['γράφ', 'γραφ,γραφτ'], ['αίρ', 'αρθ'],
      ['δέρν', 'δαρθ'], ['άσχ', 'ασχεθ'], ['καλ', 'κληθ'], ['εύχ', 'ευχηθ'], ['δίν', 'δοθ'], ['δίδ', 'δοθ'],
+     ['δεικνύ', 'δειχθ'], ['τρίβ', 'τριβ,τριφτ,τριφθ'], ['κλέπτ', 'κλαπ,κλεφτ,κλεφθ'], ['φέρ', 'φερθ'],
      ['υπόσχ', 'υποσχεθ'], ['κόπτ', 'κοπ'], ['κόβ', 'κοπ'], ['ακού', 'ακουστ'], ['στέλν', 'σταλθ,σταλ'],
      ['στέλλ', 'σταλθ,σταλ'], ['πλέν', 'πλυθ'], ['έρχ', 'έλθ,έρθ,`ρθ,`λθ'], ['κάθ', 'καθίσ,κάτσ'], ['γίν', 'γίν'],
-     ['καί', 'κα'], ['στέκ', 'σταθ'], ['στήν', 'σταθ'], ['οφείλ', 'οφεληθ'], ['πνίγ', 'πνιγ,πνιχτ'], ['θέτ', 'τεθ'],
+     ['καί', 'κα'], ['στέκ', 'σταθ'], ['στήν', 'σταθ'], ['οφείλ', 'οφεληθ'], ['πνίγ', 'πνιγ,πνιχτ,πνιχθ'], ['θέτ', 'τεθ'],
      ['βλέπ', 'ιδωθ'], ['λέγ', 'ειπωθ,ιπωθ,λεγ'], ['τείν', 'ταθ'], ['φαίν', 'φαν'], ['σέρν', 'συρθ'],
      ['αυξάν', 'αυξηθ'], ['σπέρν', 'σπαρθ'], ['αλίσκ', 'αλωθ'], ['τρέφ', 'τραφ'], ['τέμν', 'τμηθ'], ['κρέμ', 'κρεμαστ'],
      ['βρίσκ', 'βρεθ'], ['τρώ', 'φαγωθ'], ['λέ', 'ειπωθ'], ['τρώγ', 'φαγωθ'], ['αφήν', 'αφεθ'], ['τρέπ', 'τραπ'],
-     ['στρέφ', 'στραφ'], ['τίθε', 'τεθ'], ['προτίθε', 'προτεθ'], ['σέβ', 'σεβαστ'], ['χαίρ', 'χαρ'], ['λέγ', 'λεγ'],
-     ['επαφίε', 'επαφεθ'], ['ρήγνυ', 'ραγ'], ['ίστ', 'αστ'], ['θίστ', 'ταστ'], ['έλκ', 'ελκυστ'], ['χέ', 'χυσθ'],
-     ['νιστ', 'σταθ'], ['ελαύν', 'ελαθ'], ['ιστάν', 'ασταθ'], ['δεικνύ', 'δειχθ'], ['δείκνυ', 'δειχθ'],
+     ['στρέφ', 'στραφ'], ['τίθε', 'τεθ'], ['σέβ', 'σεβαστ'], ['χαίρ', 'χαρ'], ['λέγ', 'λεγ'], ['θιστ', 'ταστ'],
+     ['επαφίε', 'επαφεθ'], ['ρήγνυ', 'ραγ'], ['ίστ', 'αστ'], ['ιστ', 'αστ'], ['θίστ', 'ταστ'], ['έλκ', 'ελκυστ'], ['χέ', 'χυσθ'],
+     ['νιστ', 'σταθ,ναστ'], ['ελαύν', 'ελαθ'], ['ιστάν', 'ασταθ'], ['δεικνύ', 'δειχθ'], ['δείκνυ', 'δειχθ'],
      ['μειγνύ', 'μειχθ'], ['γιγνώσκ', 'γνωσθ'], ['πηγνύ', 'παγ'], ['ενδείκνυ', 'ενδειχθ'], ['ευρίσκ', 'ευρεθ'],
-     ['τρώ', 'φαγωθ'], ['τρώγ', 'φαγωθ'], ['σπά', 'σπαστ'], ['φυλ', 'φυλαχτ']]
+     ['τρώ', 'φαγωθ'], ['τρώγ', 'φαγωθ'], ['σπά', 'σπαστ'], ['φυλ', 'φυλαχτ'], ['άγ', 'αχθ'], ['φθείρ', 'φθαρ'],
+     ['φθείρ', 'φθαρθ'], ['πλήττ', 'πλαγ,πληγ'], ['πλήσσ', 'πλαγ,πληγ'], ['σταίν', 'στ']]
 
-irregular_passive_perfect_participles = {'αγανακτώ': 'αγανακτισμένος', 'αποτυχαίνω': 'αποτυχημένος',
-                                         'αγαπάω': 'αγαπημένος', 'αγωνίζομαι': 'αγωνισμένος',
+irregular_passive_perfect_participles = {'άγω': 'ηγμένος', 'έχομαι': None, 'αγανακτώ': 'αγανακτισμένος',
+                                         'αποτυχαίνω': 'αποτυχημένος', 'κάνω': 'καμωμένος',
+                                         'αγαπάω': 'αγαπημένος', 'αγωνίζομαι': 'αγωνισμένος', 'κάμνω': 'καμωμένος',
                                          'δυστυχώ': 'δυστυχισμένος', 'ευτυχώ': 'ευτυχισμένος', 'θυμώνω': 'θυμωμένος',
                                          'αγοράζω': 'αγορασμένος', 'αφαιρώ': 'αφηρημένος', 'αισθάνομαι': 'αισθαμένος',
                                          'ακολουθώ': 'ακολουθημένος', 'ακούω': 'ακουσμένος', 'αλλάζω': 'αλλαγμένος',
                                          'ανάβω': 'αναμμένος', 'αναγκάζω': 'αναγκασμένος', 'ανήκω': None,
-                                         'δίνω': 'δοσμένος', 'κάθομαι': 'καθισμένος', 'καίω': 'καμένος',
-                                         'κλαίω': 'κλαμένος', 'βάλλω': 'βεβλημένος',
+                                         'δίνω': 'δοσμένος', 'κάθομαι': 'καθισμένος', 'καίω': 'κεκαυμένος',
+                                         'κλαίω': 'κλαμένος', 'βάλλω': 'βεβλημένος', 'θυμάμαι': 'θυμισμένος',
                                          'τρώω': 'φαγωμένος', 'στρέφω': 'στραμμένος', 'ανοίγω': 'ανοιγμένος',
                                          'αξίζω': None, 'απαγορεύω': 'απαγορευμένος', 'απαντάω': 'απαντημένος',
                                          'αποκτώ': 'αποκτημένος', 'απορώ': None, 'αποτελούμαι': 'αποτελεσμένος',
@@ -507,7 +520,7 @@ irregular_passive_perfect_participles = {'αγανακτώ': 'αγανακτισ
                                          'εξαφανίζομαι': 'εξαφανισμένος', 'επηρεάζω': 'επηρεασμένος',
                                          'επιτρέπω': 'επιτετραμμένος', 'έρχομαι': None, 'ετοιμάζω': 'ετοιμασμένος',
                                          'εύχομαι': None, 'έχω': None, 'ζεσταίνω': 'ζεσταμένος', 'ζηλεύω': 'ζηλεμένος',
-                                         'ζητάω': 'ζητημένος', 'ζω': 'βιωμένος', 'θέλω': None, 'θυμάμαι': 'θυμημένος',
+                                         'ζητάω': 'ζητημένος', 'ζω': 'βιωμένος', 'θέλω': None,
                                          'καθαρίζω': 'καθαρισμένος', 'καλώ': 'καλεσμένος', 'καπνίζω': None,
                                          'καταλαβαίνω': None, 'καταστρέφω': 'κατεστραμμένος',
                                          'κατεβάζω': 'κατεβασμένος', 'κατεβαίνω': None, 'κερνάω': 'κερασμένος',
@@ -543,15 +556,18 @@ irregular_passive_perfect_participles = {'αγανακτώ': 'αγανακτισ
                                          'ταξιδεύω': None, 'τρελαίνομαι': 'τρελαμένος', 'τρέχω': None, 'υπάρχω': None,
                                          'υποπτεύομαι': None, 'υπόσχομαι': 'υποσχεμένος', 'υποφέρω': 'υποσχεμένος',
                                          'υποψιάζομαι': 'υποψιασμένος', 'φαίνομαι': None, 'φαντάζομαι': 'φαντασμένος',
-                                         'φέρνω': 'φερμένος', 'φεύγω': None, 'φοβάμαι': None, 'φοράω': 'φορεμένος',
+                                         'φέρνω': 'φερμένος', 'φεύγω': None, 'φοβάμαι': 'φοβισμένος',
+                                         'φοράω': 'φορεμένος', 'στήν': 'στημένος',
                                          'φταίω': 'φοβημένος', 'φτάνω': None, 'φτιάχνω': 'φτιαγμένος', 'φωνάζω': None,
                                          'χαίρομαι': 'χαρούμενος', 'χαλάω': None, 'χάνω': 'χαμένος', 'χρειάζομαι': None,
                                          'χρησιμοποιώ': 'χρησιμοποιημένος', 'χρωστάω': None, 'χτυπάω': 'χτυπημένος',
-                                         'χωράω': None, 'ψάχνω': 'ψαγμένος', 'ωφελώ': 'ωφελημένος', 'θέτω': 'τεθειμένος', 'τίθεμαι': 'τεθειμένος'}
+                                         'χωράω': None, 'ψάχνω': 'ψαγμένος', 'ωφελώ': 'ωφελημένος',
+                                         'θέτω': 'τεθειμένος', 'τίθεμαι': 'τεθειμένος'}
 
 irregular_active_aorists = {'βαίνω': 'βηκα', 'μπαίνω': 'μπήκα', 'αίρω': 'ήρα', 'βγαίνω': 'βγήκα', 'βρίσκω': 'βρήκα',
                             'πηγαίνω': 'πήγα', 'παίρνω': 'πήρα', 'λέω': 'είπα', 'λέγω': 'είπα', 'πίνω': 'ήπια',
-                            'τρώω': 'έφαγα', 'τρώγω': 'έφαγα', 'βλέπω': 'είδα', 'πάω': 'πήγα'}
+                            'τρώω': 'έφαγα', 'τρώγω': 'έφαγα', 'βλέπω': 'είδα', 'πάω': 'πήγα', 'καταλαβαίνω': 'κατάλαβα', 'καταλαμβάνω': 'κατέλαβα'}
+
 
 irregular_active_paratatikos = {'πάω': 'πήγαινα', 'σπάω': 'σπαγα'}
 
@@ -563,8 +579,10 @@ irregular_imperative_forms = {
     'σηκωθ': {SG: {SEC: 'σήκω'}},
     'ακού': {SG: {SEC: 'άκου'}},
     'ακούσ': {SG: {SEC: 'άκου'}},
-    'ανεβ': {SG: {SEC: 'ανέβα'}},
-    'κατεβ': {SG: {SEC: 'κατέβα'}},
+    'ανέβ': {SG: {SEC: 'ανέβα'}, PL: {SEC: 'ανεβείτε'}},
+    'κατέβ': {SG: {SEC: 'κατέβα'}, PL: {SEC: 'κατεβείτε'}},
+    'ανεβ': {SG: {SEC: 'ανέβα'}, PL: {SEC: 'ανεβείτε'}},
+    'κατεβ': {SG: {SEC: 'κατέβα'}, PL: {SEC: 'κατεβείτε'}},
     "φύγ": {SG: {SEC: 'φεύγα'}, PL: {SEC: 'φευγάτε'}},
     "τρέξ": {SG: {SEC: 'τρέχα'}, PL: {SEC: 'τρεχάτε'}},
     "πλύν": {PL: {SEC: 'πλύντε'}},
@@ -596,6 +614,7 @@ CON2D_PASS = 'con2d_pass'
 CON2E_PASS = 'con2e_pass'
 AOR_ACT = 'aor_act'
 ARCH_PASS_AOR = 'arch_pass_aor'
+ARCH_SEC_AOR = 'arch_sec_aor'
 PARAT_ACT_MODAL = 'parat_act_modal'
 PARAT1_PASS = 'parat1_pass'
 IMPER_ACT_CONT_1 = 'imper_act_cont_1'
@@ -618,9 +637,11 @@ PARAT2E_PASS = 'parat2e_pass'
 IMPER_ACT_AOR_A = 'imper_act_aor_a'
 IMPER_ACT_AOR_B = 'imper_act_aor_b'
 IMPER_ACT_AOR_C = 'imper_act_aor_c'
+IMPER_ACT_AOR_D = 'imper_act_aor_d'
 IMPER_ACT_AOR_CA = 'imper_act_aor_ca'
 IMPER_PASS_AOR_A = 'imper_pass_aor_a'
 IMPER_PASS_AOR_B = 'imper_pass_aor_b'
+IMPER_PASS_CONT_2SA = 'imper_pass_cont_2sa'
 PRESENT_ACTIVE_PART_1 = 'present_active_part_1'
 PRESENT_ACTIVE_PART_2C = 'present_active_part_2c'
 PRESENT_ACTIVE_PART_2 = 'present_active_part_2'
@@ -646,7 +667,7 @@ conjugations = {
     CON2B_ACT: {SG: {PRI: ['ώ'], SEC: ['είς'], TER: ['εί']}, PL: {PRI: ['ούμε'], SEC: ['είτε'], TER: ['ούνε', 'ούν']}},
     CON2C_ACT: {SG: {PRI: ['ω'], SEC: ['ς'], TER: ['ει']}, PL: {PRI: ['με'], SEC: ['τε'], TER: ['νε', 'ν']}},
     CON2D_ACT: {SG: {PRI: ['ώ'], SEC: ['οίς'], TER: ['οί']},
-                PL: {PRI: ['ούμε', 'ούμεν'], SEC: ['οίτε', 'ούτε'], TER: ['ούνε', 'ούν']}},
+                PL: {PRI: ['ούμε', 'ούμεν'], SEC: ['ούτε'], TER: ['ούνε', 'ούν']}},
     CON1_ACT_MODAL: {SG: {TER: ['ει']}},
     CON2_ACT_MODAL: {SG: {TER: ['εί']}},
 
@@ -663,14 +684,16 @@ conjugations = {
                  PL: {PRI: ['όμαστε'], SEC: ['άστε', 'όσαστε'], TER: ['ούνται']}},
     CON2SA_PASS: {SG: {PRI: ['ούμαι'], SEC: ['ούσαι'], TER: ['ούται']}, PL: {PRI: ['ούμεθα'], SEC: ['ούσθε'],
                                                                              TER: ['ούνται']}},
-    CON2D_PASS: {SG: {PRI: ['μαι'], SEC: ['σαι'], TER: ['ται']}, PL: {PRI: ['μεθα'], SEC: ['στε'],
+    CON2D_PASS: {SG: {PRI: ['μαι'], SEC: ['σαι'], TER: ['ται']}, PL: {PRI: ['μεθα'], SEC: ['σθε'],
                                                                       TER: ['νται']}},
     CON2E_PASS: {SG: {PRI: ['αμαι'], SEC: ['ασαι'], TER: ['αται']}, PL: {PRI: ['άμεθα', 'όμαστε'],
-                                                                         SEC: ['ασθε', 'άστε'],
+                                                                         SEC: ['ασθε', 'αστε'],
                                                                          TER: ['ανται']}},
 
     AOR_ACT: {SG: {PRI: ['α'], SEC: ['ες'], TER: ['ε']}, PL: {PRI: ['αμε'], SEC: ['ατε'], TER: ['αν', 'ανε']}},
     ARCH_PASS_AOR: {SG: {PRI: ['ην'], SEC: ['ης'], TER: ['η']}, PL: {PRI: ['ημεν'], SEC: ['ητε'], TER: ['ησαν']}},
+    ARCH_SEC_AOR: {SG: {PRI: ['ον'], SEC: ['ες'], TER: ['ε']}, PL: {PRI: ['ομεν'], SEC: ['ετε'], TER: ['ον']}},
+
     PARAT2_ACT: {SG: {PRI: ['α'], SEC: ['ες'], TER: ['ε']}, PL: {PRI: ['αμε'], SEC: ['ατε'], TER: ['αν', 'ανε']}},
     PARAT_ACT_MODAL: {SG: {TER: ['ε']}},
     PARAT1_PASS: {SG: {PRI: ['όμουν', 'όμουνα'], SEC: ['όσουν', 'όσουνα'], TER: ['όταν', 'ότανε']},
@@ -694,18 +717,21 @@ conjugations = {
     IMPER_ACT_EIMAI: {SG: {TER: ['έστω']}},
     IMPER_ACT_CONT_2A: {SG: {SEC: ['α', 'αγε']}, PL: {SEC: ['άτε']}},
     IMPER_ACT_CONT_2B: {SG: {SEC: ['ει']}, PL: {SEC: ['είτε']}},
-    IMPER_ACT_CONT_2D: {SG: {SEC: ['ου']}, PL: {SEC: ['ούτε', 'οίτε']}},
+    IMPER_ACT_CONT_2D: { PL: {SEC: ['οίτε']}},
     IMPER_ACT_CONT_2C: {SG: {SEC: ['γε']}, PL: {SEC: ['γετε', 'τε']}},
     IMPER_PASS_CONT_2D: {SG: {SEC: ['σο']}, PL: {SEC: ['σθε']}},
-    IMPER_PASS_CONT_2E: {SG: {SEC: ['σο']}, PL: {SEC: ['σθε']}},
+    IMPER_PASS_CONT_2E: {PL: {SEC: ['ασθε']}},
     IMPER_PASS_CONT_1: {PL: {SEC: ['εστε']}},
     IMPER_PASS_CONT_2A: {PL: {SEC: ['ιέστε']}},
     IMPER_PASS_CONT_2B: {PL: {SEC: ['είστε']}},
     IMPER_PASS_CONT_2C: {PL: {SEC: ['άστε']}},
+    IMPER_PASS_CONT_2SA: {PL: {SEC: ['ούσθε']}},
 
     IMPER_ACT_AOR_A: {SG: {SEC: ['ε']}, PL: {SEC: ['τε']}},
     IMPER_ACT_AOR_B: {SG: {SEC: ['ε']}, PL: {SEC: ['ετε']}},
     IMPER_ACT_AOR_C: {SG: {SEC: ['ες']}, PL: {SEC: ['έστε', 'είτε']}},
+    IMPER_ACT_AOR_D: {SG: {SEC: []}, PL: {SEC: ['είτε']}},
+
     IMPER_ACT_AOR_CA: {SG: {SEC: ['α']}, PL: {SEC: ['είτε']}},
     IMPER_PASS_AOR_A: {SG: {SEC: ['ου']}, PL: {SEC: ['είτε']}},
     IMPER_PASS_AOR_B: {PL: {SEC: ['είτε']}},
