@@ -11,7 +11,8 @@ from ..resources import EIMAI, PRESENT_ACTIVE_PART_EIMAI, CON1_ACT, CON1_ACT_MOD
     AOR_ACT, PRESENT_PASSIVE_PART_2B, PRESENT_ACTIVE_PART_2C, PRESENT_PASSIVE_PART_2E, PRESENT_PASSIVE_PART_1, \
     PRESENT_PASSIVE_PART_2A, PRESENT_PASSIVE_PART_2D, PRESENT_PASSIVE_PART_2AB, IMPER_ACT_CONT_1, IMPER_ACT_CONT_2B, \
     IMPER_ACT_CONT_2C, IMPER_PASS_CONT_2C, IMPER_ACT_AOR_A, IMPER_PASS_CONT_2A, IMPER_ACT_CONT_2D, IMPER_PASS_CONT_2B, \
-    IMPER_PASS_CONT_2D, IMPER_PASS_CONT_2E, IMPER_ACT_AOR_B, IMPER_ACT_AOR_C
+    IMPER_PASS_CONT_2D, IMPER_PASS_CONT_2E, IMPER_ACT_AOR_B, IMPER_ACT_AOR_C, IMPER_ACT_AOR_D, ROOT, ARCH_SEC_AOR, \
+    CON2SA_PASS, IMPER_PASS_CONT_2SA
 
 
 def create_imp_pass(perf_pass_root):
@@ -46,22 +47,25 @@ def create_regular_perf_root(verb, voice=ACTIVE):
     perf_root = None
     irregular = False
 
+
+
     multiple_stems = None
     if verb[-1] in ['ω', 'ώ'] or verb[-2:] in ['ει', 'εί'] or verb[-5:] == 'είμαι':
         res = recognize_active_non_past_conjugation(verb)
 
+
     else:
         res = recognize_passive_present_continuous_conjugation(verb)
 
     if not res:
         return None
 
-    root = res['root']
+    root = res[ROOT]
     conjugation = res['conjugation_ind']
 
     if conjugation == MODAL:
         perf_root = root
-
+    no_perfect_root = False
     # an idea: to solve problem with irregular verbs that cannot be simply caught because they are combined with
     # some suffix
 
@@ -78,6 +82,7 @@ def create_regular_perf_root(verb, voice=ACTIVE):
                 for stem in pair[1].split(','):
 
                     if len(root) >= len(pair[0]) and root[-len(pair[0]):] == pair[0]:
+
                         beta_perf_root = root[:-len(pair[0])] + stem
 
                         if (beta_perf_root + 'ω' in greek_corpus) or (
@@ -90,17 +95,21 @@ def create_regular_perf_root(verb, voice=ACTIVE):
                     irregular = True
                     multiple_stems = True
                     break
-
             if len(root) >= len(pair[0]) and root[-len(pair[0]):] == pair[0]:
+
                 beta_perf_root = root[:-len(pair[0])] + pair[1]
+
                 if (beta_perf_root + 'ω' in greek_corpus) or (
                         beta_perf_root + 'ώ' in greek_corpus):
+
                     perf_root = beta_perf_root
                     irregular = True
                     break
 
     if voice == PASSIVE:
         for pair in irregular_passive_roots:
+
+
             if ',' in pair[1]:
                 # that is if many stems
                 multiple_perf_roots = []
@@ -119,7 +128,7 @@ def create_regular_perf_root(verb, voice=ACTIVE):
                     multiple_stems = True
                     break
 
-            if len(root) >= len(pair[0]) and root[-len(pair[0]):] == pair[0]:
+            if len(root) >= len(pair[0]) and root[-len(pair[0]):] == pair[0] and pair[1]:
 
                 for r in pair[1].split(','):
 
@@ -181,6 +190,14 @@ def create_regular_perf_root(verb, voice=ACTIVE):
         elif root[-1] in ['ρ', 'λ', 'μ', 'ψ', 'σ']:
             perf_root = root
 
+            if root[-2:] == 'άρ':
+                # arisw
+                if put_accent_on_the_penultimate(root + 'ισω') in greek_corpus or put_accent_on_the_antepenultimate(root + 'ισε'):
+                    perf_root = perf_root + ',' + put_accent_on_the_ultimate(root + 'ισ')
+                    multiple_stems = True
+
+
+
         elif root in ['επέστη']:
             # ancient form
             perf_root = root
@@ -197,10 +214,10 @@ def create_regular_perf_root(verb, voice=ACTIVE):
         elif root[-2:] == 'ρν' and conjugation in [CON2A_ACT, CON2A_PASS] and perf_root + 'ω' not in greek_corpus:
             perf_root = root[:-1] + 'άσ'
         elif conjugation in [CON2B_ACT, CON2A_ACT]:
-            perf_root = root + 'ίσ'
+            perf_root = root + 'ήσ'
 
             if perf_root + 'ω' not in greek_corpus:
-                perf_root = root + 'ήσ'
+                perf_root = root + 'ίσ'
 
         if not ((perf_root + 'ω' in greek_corpus) or (perf_root + 'ου' in greek_corpus) or
                 (perf_root + 'ει' in greek_corpus)):
@@ -258,6 +275,7 @@ def create_regular_perf_root(verb, voice=ACTIVE):
     if voice == PASSIVE and conjugation in [CON1_ACT, CON1_PASS, CON1_PASS_MODAL,
                                             CON2_PASS_MODAL, CON2D_ACT, CON2D_PASS] and not irregular:
 
+        perf_root = None
         root = remove_all_diacritics(root)
         if root[-3:] == 'αιν':
             perf_root = root[:-3] + 'ανθ'
@@ -267,14 +285,15 @@ def create_regular_perf_root(verb, voice=ACTIVE):
                     perf_root = root[:-2] + 'θ'
                     if perf_root + 'ώ' not in greek_corpus:
                         perf_root = root[:-2] + 'χτ'
+
                         if perf_root + 'ώ' not in greek_corpus:
                             perf_root = root[:-2] + 'στ'
         elif root[-2:] in ['σσ', 'ττ', 'χν', 'σκ']:
             perf_root = root[:-2] + 'χτ'
 
-        elif len(root) > 5 and root[-6:] == 'δεικνυ':
-
-            perf_root = root[:-3] + 'χτ'
+        # elif len(root) > 5 and root[-6:] == 'δεικνυ':
+        #
+        #     perf_root = root[:-3] + 'χτ'
 
         elif root[-2:] in ['πτ', 'φτ']:
             perf_root = root[:-2] + 'φτ'
@@ -290,32 +309,47 @@ def create_regular_perf_root(verb, voice=ACTIVE):
             perf_root = root[:-1] + 'στ'
 
         elif root[-1] == 'ζ':
+
             perf_root = root[:-1] + 'χτ'
             if perf_root + 'ώ' not in greek_corpus:
                 perf_root = root[:-1] + 'στ'
-                if perf_root + 'ώ' not in greek_corpus:
+
+                if perf_root + 'ώ' not in greek_corpus and root[:-1] + 'θώ' in greek_corpus:
                     perf_root = root[:-1] + 'θ'
 
         elif root[-1] in ['κ', 'χ', 'γ']:
+            if root[-2:] in ['γγ']:
+                root = root[:-1]
             perf_root = root[:-1] + 'χτ'
-            if perf_root + 'ώ' not in greek_corpus:
-                perf_root = root[:-1] + 'χτ'
+            if perf_root + 'εί' not in greek_corpus and root[:-1] + 'χθώ' in greek_corpus:
+                perf_root = root[:-1] + 'χθ'
 
         elif root[-1] in ['β', 'π', 'φ', 'ψ']:
             perf_root = root[:-1] + 'φτ'
-
+            if perf_root + 'ώ' not in greek_corpus and root[:-1] + 'φθώ' in greek_corpus:
+                perf_root = root[:-1] + 'φθ'
         elif root[-2:] in ['ευ', 'αυ']:
             perf_root = root + 'τ'
-
-        elif root[-1] in ['υ', 'ρ', 'λ', 'ι', 'μ', 'ε']:
-            perf_root = root + 'ηθ'
-            if perf_root + 'ώ' not in greek_corpus:
+            if perf_root + 'ώ' not in greek_corpus and root + 'θώ' in greek_corpus:
                 perf_root = root + 'θ'
+        elif root[-1] in ['υ', 'ρ', 'λ', 'ι', 'μ', 'ε']:
+            if root + 'ηθώ' in greek_corpus:
+                perf_root = root + 'ηθ'
+            if root + 'ώ' in greek_corpus:
+                perf_root = root
+            if root[-2:] == 'αρ':
+                if root + 'ιστώ' in greek_corpus or root + 'ιστεί' in greek_corpus or root + 'ισμένος':
+                    perf_root = root + 'ιστ'
+
 
         if conjugation == CON2D_ACT:
             perf_root = root + 'ωθ'
         if perf_root:
             perf_root = remove_all_diacritics(perf_root)
+        if perf_root and perf_root[-2:] == "χτ":
+            if perf_root + 'εί' not in greek_corpus and perf_root[:-1] + 'θεί' in greek_corpus:
+                perf_root = perf_root[:-1] + 'Θ'
+
 
     if voice == PASSIVE and \
             conjugation in [CON2A_ACT, CON2B_ACT, CON2C_ACT, CON2A_PASS, CON2B_PASS, CON2E_PASS,
@@ -326,6 +360,7 @@ def create_regular_perf_root(verb, voice=ACTIVE):
         if root[-2:] in ['ρν', 'χν'] and (perf_root + 'ώ' not in greek_corpus):
             perf_root = root[:-1] + 'αστ'
         # εξαιρέσεις
+
         if not (perf_root + 'ώ' in greek_corpus):
 
             if conjugation in [CON2A_ACT, CON2B_ACT, CON2B_PASS, CON2B_PASS, CON2A_PASS, CON2AB]:
@@ -391,6 +426,7 @@ def recognize_active_non_past_conjugation(verb, aspect=IMPERF, tense=FIN, voice=
         conjugation_ind = CON2C_ACT
         conjugation_imp = IMPER_ACT_CONT_2C
         conjugation_part = PRESENT_ACTIVE_PART_2C
+
     elif (verb[-1] == 'ώ') or (verb[-1:] == 'ω' and count_syllables(verb) == 1):
         root = verb[:-1]
 
@@ -398,17 +434,19 @@ def recognize_active_non_past_conjugation(verb, aspect=IMPERF, tense=FIN, voice=
         conjugation_imp = IMPER_ACT_CONT_2B
         conjugation_part = PRESENT_ACTIVE_PART_2
         # contracted άω to ώ
-        if verb[:-1] + 'είς' not in greek_corpus and verb[:-1] + 'ά' in greek_corpus or (
+
+        if (put_accent_on_the_ultimate(verb[:-1] + 'είς', accent_one_syllable=False) not in greek_corpus and verb[:-1] + 'ά' in greek_corpus or (
                 verb[:-1] + 'άς' in greek_corpus and
                 verb[:-1] + 'άτε' in greek_corpus
-        ):
+        )) and aspect != PERF:
 
             conjugation_ind = CON2A_ACT
             conjugation_imp = IMPER_ACT_CONT_2A
             conjugation_part = PRESENT_ACTIVE_PART_2
 
 
-        elif verb[:-1] + 'είς' not in greek_corpus and verb[:-1] + 'οί' in greek_corpus:
+
+        elif verb[:-1] + 'είς' not in greek_corpus and verb[:-1] + 'οί' in greek_corpus and aspect != PERF:
 
             conjugation_ind = CON2D_ACT
             conjugation_imp = IMPER_ACT_CONT_2D
@@ -445,7 +483,7 @@ def recognize_active_non_past_conjugation(verb, aspect=IMPERF, tense=FIN, voice=
 
     else:
         # else it's assumed it's modal
-        return {'aspect': aspect, 'tense': tense, 'voice': voice, 'root': verb,
+        return {'aspect': aspect, 'tense': tense, 'voice': voice, ROOT: verb,
                 'conjugation_ind': MODAL, 'conjugation_imp': '', 'conjugation_part': ''}
 
     if aspect == PERF:
@@ -456,6 +494,8 @@ def recognize_active_non_past_conjugation(verb, aspect=IMPERF, tense=FIN, voice=
 
         if count_syllables(verb) == 1:
             conjugation_imp = IMPER_ACT_AOR_C
+        elif conjugation_ind == CON2B_ACT or verb in ['κατέβω', 'ανέβω']:
+            conjugation_imp = IMPER_ACT_AOR_D
         elif root == '':
             # sometimes there is no simple future form
             pass
@@ -472,7 +512,7 @@ def recognize_active_non_past_conjugation(verb, aspect=IMPERF, tense=FIN, voice=
 
         conjugation_imp = IMPER_PASS_AOR_A
     return {'aspect': aspect, 'voice': voice, 'tense': tense,
-            'root': root,
+            ROOT: root,
             'conjugation_ind': conjugation_ind,
             'conjugation_imp': conjugation_imp,
             'conjugation_part': conjugation_part}
@@ -503,6 +543,11 @@ def recognize_passive_present_continuous_conjugation(verb):
         conjugation_ind = CON2B_PASS
         conjugation_imp = IMPER_PASS_CONT_2B
         conjugation_part = PRESENT_PASSIVE_PART_2B
+        con_act = recognize_active_non_past_conjugation(verb[:-5] + 'ώ')
+        if con_act['conjugation_ind'] == CON2D_ACT:
+            conjugation_ind = CON2SA_PASS
+            conjugation_imp = IMPER_PASS_CONT_2SA
+
 
     elif verb[-4:] == 'άμαι':
         root = verb[:-4]
@@ -545,10 +590,10 @@ def recognize_passive_present_continuous_conjugation(verb):
         conjugation_part = ''
 
     else:
-        return {'aspect': IMPERF, 'voice': PASSIVE, 'tense': FIN, 'root': verb,
+        return {'aspect': IMPERF, 'voice': PASSIVE, 'tense': FIN, ROOT: verb,
                 'conjugation_ind': MODAL, 'conjugation_imp': '', 'conjugation_part': ''}
 
-    return {'aspect': IMPERF, 'voice': PASSIVE, 'tense': FIN, 'root': root,
+    return {'aspect': IMPERF, 'voice': PASSIVE, 'tense': FIN, ROOT: root,
             'conjugation_ind': conjugation_ind, 'conjugation_imp': conjugation_imp,
             'conjugation_part': conjugation_part}
 
@@ -568,6 +613,9 @@ def recognize_past_conjugation(verb, lemma, aspect=IMPERF, voice=ACTIVE):
 
     elif verb[-1] in ['ν', 'η']:
         conjugation_ind = ARCH_PASS_AOR
+        if verb[-2:] == 'ον':
+            conjugation_ind = ARCH_SEC_AOR
+            root = verb[:-2]
 
     elif verb[-1] != 'α':
         conjugation_ind = MODAL
@@ -579,7 +627,7 @@ def recognize_past_conjugation(verb, lemma, aspect=IMPERF, voice=ACTIVE):
     if voice == PASSIVE and aspect == IMPERF:
         root, conjugation_ind = recognize_passive_past_continuous_conjugation(lemma, verb)
 
-    return {'aspect': aspect, 'voice': voice, 'tense': PAST, 'root': root,
+    return {'aspect': aspect, 'voice': voice, 'tense': PAST, ROOT: root,
             'conjugation_ind': conjugation_ind}
 
 
